searchNodes=[{"doc":"Documentation for MjmlEEx template module. This moule contains the macro that is used to create an MJML EEx template. You can use this module like so: defmodule BasicTemplate do use MjmlEEx , mjml_template : &quot;basic_template.mjml.eex&quot; end Along with the basic_template.mjml.eex MJML template located in the same directory as the module containing the following: &lt;mjml&gt; &lt;mj-body&gt; &lt;mj-section&gt; &lt;mj-column&gt; &lt;mj-divider border-color=&quot;#F45E43&quot;&gt;&lt;/mj-divider&gt; &lt;mj-text font-size=&quot;20px&quot; color=&quot;#F45E43&quot;&gt;Hello &lt;%= @first_name %&gt; &lt;%= @last_name %&gt;!&lt;/mj-text&gt; &lt;/mj-column&gt; &lt;/mj-section&gt; &lt;/mj-body&gt; &lt;/mjml&gt; Once that is in place, you can render the final HTML document by running: BasicTemplate . render ( first_name : &quot;Alex&quot; , last_name : &quot;Koutmos&quot; )","ref":"MjmlEEx.html","title":"MjmlEEx","type":"module"},{"doc":"This module allows you to define a reusable MJML component that can be injected into an MJML template prior to it being rendered into HTML. To do so, create an MjmlEEx.Component module that looks like so: defmodule HeadBlock do use MjmlEEx.Component @impl true def render ( _opts ) do &quot;&quot;&quot; &lt;mj-head&gt; &lt;mj-title&gt;Hello world!&lt;/mj-title&gt; &lt;mj-font name=&quot;Roboto&quot; href=&quot;https://fonts.googleapis.com/css?family=Montserrat:300,400,500&quot;&gt;&lt;/mj-font&gt; &lt;/mj-head&gt; &quot;&quot;&quot; end end With that in place, anywhere that you would like to use the component, you can add: &lt;%= render_component HeadBlock %&gt; in your MJML EEx template. You can also pass options to the render function like so: defmodule HeadBlock do use MjmlEEx.Component @impl true def render ( opts ) do &quot;&quot;&quot; &lt;mj-head&gt; &lt;mj-title&gt; \#{ opts [ :title ] } &lt;/mj-title&gt; &lt;mj-font name=&quot;Roboto&quot; href=&quot;https://fonts.googleapis.com/css?family=Montserrat:300,400,500&quot;&gt;&lt;/mj-font&gt; &lt;/mj-head&gt; &quot;&quot;&quot; end end And calling it like so: &lt;%= render_component(HeadBlock, title: &quot;Some really cool title&quot;) %&gt;","ref":"MjmlEEx.Component.html","title":"MjmlEEx.Component","type":"behaviour"},{"doc":"Returns the MJML markup for the component as a string.","ref":"MjmlEEx.Component.html#c:render/1","title":"MjmlEEx.Component.render/1","type":"callback"},{"doc":"This Engine is used to compile the MJML template.","ref":"MjmlEEx.Engines.Mjml.html","title":"MjmlEEx.Engines.Mjml","type":"module"},{"doc":"This module allows you to define an MJML layout so that you can create reusable email skeletons. To use layouts with your MJML emails, create a layout template that contains an &lt;%= @inner_content %&gt; expression in it like so: &lt;mjml&gt; &lt;mj-head&gt; &lt;mj-title&gt;Say hello to card&lt;/mj-title&gt; &lt;mj-font name=&quot;Roboto&quot; href=&quot;https://fonts.googleapis.com/css?family=Montserrat:300,400,500&quot;&gt;&lt;/mj-font&gt; &lt;mj-attributes&gt; &lt;mj-all font-family=&quot;Montserrat, Helvetica, Arial, sans-serif&quot;&gt;&lt;/mj-all&gt; &lt;mj-text font-weight=&quot;400&quot; font-size=&quot;16px&quot; color=&quot;#000000&quot; line-height=&quot;24px&quot;&gt;&lt;/mj-text&gt; &lt;mj-section padding=&quot;&lt;%= @padding %&gt;&quot;&gt;&lt;/mj-section&gt; &lt;/mj-attributes&gt; &lt;/mj-head&gt; &lt;%= @inner_content %&gt; &lt;/mjml&gt; You can also include additional assigns like @padding in this example. Just make sure that you provide that assign when you are rendering the final template. With that in place, you can define a layout module like so defmodule BaseLayout do use MjmlEEx.Layout , mjml_layout : &quot;base_layout.mjml.eex&quot; end And then use it in conjunction with your templates like so: defmodule MyTemplate do use MjmlEEx , mjml_template : &quot;my_template.mjml.eex&quot; , layout : BaseLayout end Then in your template, all you need to provide are the portions that you need to complete the layout: &lt;mj-body&gt; ... &lt;/mj-body&gt;","ref":"MjmlEEx.Layout.html","title":"MjmlEEx.Layout","type":"module"},{"doc":"General MJML EEx utils reside here for encoding and decoding Elixir expressions in MJML EEx templates.","ref":"MjmlEEx.Utils.html","title":"MjmlEEx.Utils","type":"module"},{"doc":"This function finds all of the instances of of encoded EEx expressions and decodes them so that when the EEx HTML template is finally rendered, the expressions are executed as expected.","ref":"MjmlEEx.Utils.html#decode_eex_expressions/1","title":"MjmlEEx.Utils.decode_eex_expressions/1","type":"function"},{"doc":"This function encodes the internals of an MJML EEx document so that when it is compiled, the EEx expressions don't break the MJML compiler.","ref":"MjmlEEx.Utils.html#encode_expression/2","title":"MjmlEEx.Utils.encode_expression/2","type":"function"},{"doc":"This function goes through and espaces all non-special EEx expressions so that they do not throw off the the MJML compiler.","ref":"MjmlEEx.Utils.html#escape_eex_expressions/1","title":"MjmlEEx.Utils.escape_eex_expressions/1","type":"function"},{"doc":"Easily create beautiful emails using MJML right from Elixir! Contents Installation Supporting MJML EEx Using MJML EEx Attribution","ref":"readme.html","title":"README","type":"extras"},{"doc":"Available in Hex , the package can be installed by adding mjml_eex to your list of dependencies in mix.exs : def deps do [ { :mjml_eex , &quot;~&gt; 0.5.0&quot; } ] end Documentation can be found at https://hexdocs.pm/mjml_eex .","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"If you rely on this library to generate awesome looking emails for your application, it would much appreciated if you can give back to the project in order to help ensure its continued development. Checkout my GitHub Sponsorship page if you want to help out! Gold Sponsors Silver Sponsors Bronze Sponsors","ref":"readme.html#supporting-mjml-eex","title":"README - Supporting MJML EEx","type":"extras"},{"doc":"Basic Usage Add {:mjml_eex, &quot;~&gt; 0.5.0&quot;} to your mix.exs file and run mix deps.get . After you have that in place, you can go ahead and create a template module like so: defmodule BasicTemplate do use MjmlEEx , mjml_template : &quot;basic_template.mjml.eex&quot; end And the accompanying MJML EEx template basic_template.mjml.eex (note that the path is relative to the calling module path): &lt;mjml&gt; &lt;mj-body&gt; &lt;mj-section&gt; &lt;mj-column&gt; &lt;mj-divider border-color=&quot;#F45E43&quot;&gt;&lt;/mj-divider&gt; &lt;mj-text font-size=&quot;20px&quot; color=&quot;#F45E43&quot;&gt;Hello &lt;%= @first_name %&gt; &lt;%= @last_name %&gt;!&lt;/mj-text&gt; &lt;/mj-column&gt; &lt;/mj-section&gt; &lt;/mj-body&gt; &lt;/mjml&gt; With those two in place, you can now run BasicTemplate.render(first_name: &quot;Alex&quot;, last_name: &quot;Koutmos&quot;) and you will get back an HTML document that can be emailed to users. Using Functions from Template Module You can also call functions from your template module if they exist in your MJML EEx template using the following module declaration: defmodule FunctionTemplate do use MjmlEEx , mjml_template : &quot;function_template.mjml.eex&quot; defp generate_full_name ( first_name , last_name ) do &quot; \#{ first_name } \#{ last_name } &quot; end end In conjunction with the following template: &lt;mjml&gt; &lt;mj-body&gt; &lt;mj-section&gt; &lt;mj-column&gt; &lt;mj-divider border-color=&quot;#F45E43&quot;&gt;&lt;/mj-divider&gt; &lt;mj-text font-size=&quot;20px&quot; color=&quot;#F45E43&quot;&gt;Hello &lt;%= generate_full_name(@first_name, @last_name) %&gt;!&lt;/mj-text&gt; &lt;/mj-column&gt; &lt;/mj-section&gt; &lt;/mj-body&gt; &lt;/mjml&gt; In order to render the email you would then call: FunctionTemplate.render(first_name: &quot;Alex&quot;, last_name: &quot;Koutmos&quot;) Using Components In addition to compiling single MJML EEx templates, you can also create MJML partials and include them in other MJML templates AND components using the special render_component function. With the following modules: defmodule FunctionTemplate do use MjmlEEx , mjml_template : &quot;component_template.mjml.eex&quot; end defmodule HeadBlock do use MjmlEEx.Component @impl true def render ( _opts ) do &quot;&quot;&quot; &lt;mj-head&gt; &lt;mj-title&gt;Hello world!&lt;/mj-title&gt; &lt;mj-font name=&quot;Roboto&quot; href=&quot;https://fonts.googleapis.com/css?family=Montserrat:300,400,500&quot;&gt;&lt;/mj-font&gt; &lt;/mj-head&gt; &quot;&quot;&quot; end end And the following template: &lt;mjml&gt; &lt;%= render_component HeadBlock %&gt; &lt;mj-body&gt; &lt;mj-section&gt; &lt;mj-column&gt; &lt;mj-divider border-color=&quot;#F45E43&quot;&gt;&lt;/mj-divider&gt; &lt;mj-text font-size=&quot;20px&quot; color=&quot;#F45E43&quot;&gt;Hello &lt;%= generate_full_name(@first_name, @last_name) %&gt;!&lt;/mj-text&gt; &lt;/mj-column&gt; &lt;/mj-section&gt; &lt;/mj-body&gt; &lt;/mjml&gt; Be sure to look at the MjmlEEx.Component for additional usage information as you can also pass options to your template and use them when generating the partial string. Using Layouts Often times, you'll want to create an Email skeleton or layout using MJML, and then inject your template into that layout. MJML EEx supports this functionality which makes it really easy to have business branded emails application wide without having to copy and paste the same boilerplate in every template. To create a layout, define a layout module like so: defmodule BaseLayout do use MjmlEEx.Layout , mjml_layout : &quot;base_layout.mjml.eex&quot; end And an accompanying layout like so: &lt;mjml&gt; &lt;mj-head&gt; &lt;mj-title&gt;Say hello to card&lt;/mj-title&gt; &lt;mj-font name=&quot;Roboto&quot; href=&quot;https://fonts.googleapis.com/css?family=Montserrat:300,400,500&quot;&gt;&lt;/mj-font&gt; &lt;mj-attributes&gt; &lt;mj-all font-family=&quot;Montserrat, Helvetica, Arial, sans-serif&quot;&gt;&lt;/mj-all&gt; &lt;mj-text font-weight=&quot;400&quot; font-size=&quot;16px&quot; color=&quot;#000000&quot; line-height=&quot;24px&quot;&gt;&lt;/mj-text&gt; &lt;mj-section padding=&quot;&lt;%= @padding %&gt;&quot;&gt;&lt;/mj-section&gt; &lt;/mj-attributes&gt; &lt;/mj-head&gt; &lt;%= @inner_content %&gt; &lt;/mjml&gt; As you can see, you can include assigns in your layout template (like @padding ), but you also need to include a mandatory @inner_content expression. That way, MJML EEx knowns where to inject your template into the layout. With that in place, you just need to tell your template module what layout to use (if you are using a layout that is): defmodule MyTemplate do use MjmlEEx , mjml_template : &quot;my_template.mjml.eex&quot; , layout : BaseLayout end And your template file can contain merely the parts that you need for that particular template: &lt;mj-body&gt; ... &lt;/mj-body&gt;","ref":"readme.html#using-mjml-eex","title":"README - Using MJML EEx","type":"extras"},{"doc":"The logo for the project is an edited version of an SVG image from the unDraw project The Elixir MJML library that this library builds on top of MJML The Rust MRML library that provides the MJML compilation functionality MRML","ref":"readme.html#attribution","title":"README - Attribution","type":"extras"}]